## venra

[![PyPI version](https://badge.fury.io/py/venra.svg)](https://badge.fury.io/py/venra)


### Install

```bash
$ pip install venra
```

### Usage


```python

import venra

print(venra.stars)
```
